@@ -3,6 +3,9 @@
  *
  * SPDX-License-Identifier: LGPL-2.1+
  */
+
+#pragma once
+
 /**
  * SECTION:fwupd-version
  * @short_description: Obtains the version for the installed fwupd
@@ -15,9 +18,6 @@
 #error "Only <fwupd.h> can be included directly."
 #endif
 
-#ifndef __FWUPD_VERSION_H
-#define __FWUPD_VERSION_H
-
 /**
  * FWUPD_MAJOR_VERSION:
  *
@@ -42,7 +42,7 @@
  * The compile-time micro version
  */
 #ifndef FWUPD_MICRO_VERSION
-#define FWUPD_MICRO_VERSION				(3)
+#define FWUPD_MICRO_VERSION				(9)
 #endif
 
 /**
@@ -59,5 +59,3 @@
      (FWUPD_MAJOR_VERSION == (major) && FWUPD_MINOR_VERSION > (minor)) || \
      (FWUPD_MAJOR_VERSION == (major) && FWUPD_MINOR_VERSION == (minor) && \
       FWUPD_MICRO_VERSION >= (micro)))
-
-#endif /* __FWUPD_VERSION_H */
